@@ -8,15 +8,14 @@ from silly_db.db import DB
 from geninstaller import __version__
 from geninstaller import core
 from geninstaller import ploppers
+from geninstaller.plop.gui.gui_installer import install_gui
 from geninstaller.helpers import (
-    BASE_DIR,
     GI_DIR,
     APP_FILES_DIR,
-    APP_DIR,
     DB_FILE,
     no_db,
     display_list,
-    clean_name,
+    get_db,
 )
 
 
@@ -26,10 +25,9 @@ def list(*args):
     db = DB(
         file=DB_FILE,
         base=GI_DIR,
-        # migrations_dir="None",  # delete with silly-db v 1.1.4
     )
     App = db.model("application")
-    apps = App.all()
+    apps = App.sil.all()
     display_list(apps)
 
 
@@ -46,14 +44,15 @@ def open_apps_dir(*args):
     os.system(f"xdg-open {APP_FILES_DIR}")
 
 
-def search(name, *args):
+def search(name=None, *args):
     name = name
+    if name is None:
+        return list()
     if no_db():
         return
     db = DB(
         file=DB_FILE,
         base=GI_DIR,
-        # migrations_dir="None",  # delete with silly-db v 1.1.3
     )
     apps = db.select(f"* FROM application WHERE name LIKE '%{name}%'")
     display_list(apps)
@@ -62,9 +61,7 @@ def search(name, *args):
 def cmd():
     routes = [
         "HELP",
-        ("-h", cli.help, "display this help"),
-        ("--help", cli.help, "idem"),
-        ("", cli.help, "idem"),
+        (["", "-h", "--help"], cli.help, "display this help"),
         "ACTIONS",
         ('list', list, "list the applications installed with geninstaller"),
         ('search <name>', search,
@@ -72,6 +69,8 @@ def cmd():
         ('uninstall <name>', core.uninstall, (
             "uninstall an application with its exact name, "
             "use '' if the 'app name' contains a blank space")),
+        "GUI",
+        ('gui', install_gui, "Installs the graphical interface on your system"),
         "OPEN DIRECTORIES",
         ('open', open_apps_dir,
             "open the applications installation directory"),
@@ -92,4 +91,6 @@ def cmd():
 
 
 if __name__ == "__main__":
-    cmd()
\ No newline at end of file
+    db = get_db()
+    db.migrate_all()
+    cmd()
